<?php

namespace Drupal\ckeditor_plugin_report\Controller;

use Drupal\ckeditor5\Plugin\CKEditor5PluginManagerInterface;
use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * The PluginReportController controller.
 */
class PluginReportController extends ControllerBase {

  /**
   * The CKEditor 5 plugin manager, if the service is defined.
   *
   * @var \Drupal\ckeditor5\Plugin\CKEditor5PluginManagerInterface|null
   */
  protected $ckeditor5PluginManager;

  /**
   * Constructor.
   *
   * @param \Drupal\ckeditor5\Plugin\CKEditor5PluginManagerInterface|null $ckeditor5_plugin_manager
   *   The CKEditor 5 plugin manager, if the service is defined.
   */
  public function __construct(CKEditor5PluginManagerInterface|null $ckeditor5_plugin_manager) {
    $this->ckeditor5PluginManager = $ckeditor5_plugin_manager;
  }

  /**
   * {@inheritdoc}
   *
   * @param \Symfony\Component\DependencyInjection\ContainerInterface $container
   *   The Drupal service container.
   *
   * @return static
   */
  public static function create(ContainerInterface $container) {
    return new static(
      // Since this module declares no dependencies, it's possible that
      // CKEditor 5 may not be installed.
      $container->get('plugin.manager.ckeditor5.plugin', ContainerInterface::NULL_ON_INVALID_REFERENCE)
    );
  }

  /**
   * Returns the report render array.
   */
  public function content() {
    $build = [];

    $build['intro'] = [
      '#markup' => $this->t('<p>Below are CKEditor plugins as returned by their respective plugin managers:</p>'),
    ];

    $table_template = [
      '#type' => 'table',
      '#header' => [
        $this->t('Plugin ID'),
        $this->t('Provider'),
        $this->t('Class'),
      ],
      '#empty' => $this->t('No plugins found.'),
    ];

    if ($this->ckeditor5PluginManager) {
      $build['ckeditor5_plugins'] = [
        '#type' => 'details',
        '#title' => $this->t('CKEditor 5 plugins'),
        '#attributes' => [
          'class' => ['ckeditor5-plugins'],
        ],
      ];

      $build['ckeditor5_plugins']['table'] = $table_template;

      $definitions = $this->ckeditor5PluginManager->getDefinitions();
      foreach ($definitions as $definitions) {
        $build['ckeditor5_plugins']['table']['#rows'][] = [
          $definitions->id(),
          $definitions->getProvider(),
          $definitions->getClass(),
        ];
      }
    }

    return $build;
  }

}
